==> ldap-account-manager_8.3.orig.tar.bz2: ldap-account-manager-8.3/templates/lib/extra/ckeditor/plugins/link/lang/no.js <==
﻿/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'no', {
	acccessKey: 'Aksessknapp',
	advanced: 'Avansert',
	advisoryContentType: 'Type',
	advisoryTitle: 'Tittel',
	anchor: {
		toolbar: 'Sett inn/Rediger anker',
		menu: 'Egenskaper for anker',
		title: 'Egenskaper for anker',
		name: 'Ankernavn',
		errorName: 'Vennligst skriv inn ankernavnet',
		remove: 'Fjern anker'
	},
	anchorId: 'Element etter ID',
	anchorName: 'Anker etter navn',
	charset: 'Lenket tegnsett',
	cssClasses: 'Stilarkklasser',
	download: 'Force Download', // MISSING
	displayText: 'Tekst som skal vises',
	emailAddress: 'E-postadresse',
	emailBody: 'Melding',
	emailSubject: 'Meldingsemne',
	id: 'Id',
	info: 'Lenkeinfo',
	langCode: 'Språkkode',
	langDir: 'Språkretning',
	langDirLTR: 'Venstre til høyre (VTH)',
	langDirRTL: 'Høyre til venstre (HTV)',
	menu: 'Rediger lenke',
	name: 'Navn',
	noAnchors: '(Ingen anker i dokumentet)',
	noEmail: 'Vennligst skriv inn e-postadressen',
	noUrl: 'Vennligst skriv inn lenkens URL',
	noTel: 'Skriv inn telefonnummer',
	other: '<annen>',
	phoneNumber: 'Telefonnummer',
	popupDependent: 'Avhenging (Netscape)',
	popupFeatures: 'Egenskaper for popup-vindu',
	popupFullScreen: 'Fullskjerm (IE)',
	popupLeft: 'Venstre posisjon',
	popupLocationBar: 'Adresselinje',
	popupMenuBar: 'Menylinje',
	popupResizable: 'Skalerbar',
	popupScrollBars: 'Scrollbar',
	popupStatusBar: 'Statuslinje',
	popupToolbar: 'Verktøylinje',
	popupTop: 'Topp-posisjon',
	rel: 'Relasjon (rel)',
	selectAnchor: 'Velg et anker',
	styles: 'Stil',
	tabIndex: 'Tabindeks',
	target: 'Mål',
	targetFrame: '<ramme>',
	targetFrameName: 'Målramme',
	targetPopup: '<popup-vindu>',
	targetPopupName: 'Navn på popup-vindu',
	title: 'Lenke',
	toAnchor: 'Lenke til anker i teksten',
	toEmail: 'E-post',
	toUrl: 'URL',
	toPhone: 'Telefon',
	toolbar: 'Sett inn/Rediger lenke',
	type: 'Lenketype',
	unlink: 'Fjern lenke',
	upload: 'Last opp'
} );

==> ldap-account-manager_8.5.orig.tar.bz2: ldap-account-manager-8.5/templates/lib/extra/ckeditor/plugins/link/lang/no.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'link', 'no', {
	acccessKey: 'Aksessknapp',
	advanced: 'Avansert',
	advisoryContentType: 'Type',
	advisoryTitle: 'Tittel',
	anchor: {
		toolbar: 'Sett inn/Rediger anker',
		menu: 'Egenskaper for anker',
		title: 'Egenskaper for anker',
		name: 'Ankernavn',
		errorName: 'Vennligst skriv inn ankernavnet',
		errorWhitespace: 'Anchor name cannot contain space characters', // MISSING
		remove: 'Fjern anker'
	},
	anchorId: 'Element etter ID',
	anchorName: 'Anker etter navn',
	charset: 'Lenket tegnsett',
	cssClasses: 'Stilarkklasser',
	download: 'Force Download', // MISSING
	displayText: 'Tekst som skal vises',
	emailAddress: 'E-postadresse',
	emailBody: 'Melding',
	emailSubject: 'Meldingsemne',
	id: 'Id',
	info: 'Lenkeinfo',
	langCode: 'Språkkode',
	langDir: 'Språkretning',
	langDirLTR: 'Venstre til høyre (VTH)',
	langDirRTL: 'Høyre til venstre (HTV)',
	menu: 'Rediger lenke',
	name: 'Navn',
	noAnchors: '(Ingen anker i dokumentet)',
	noEmail: 'Vennligst skriv inn e-postadressen',
	noUrl: 'Vennligst skriv inn lenkens URL',
	noTel: 'Skriv inn telefonnummer',
	other: '<annen>',
	phoneNumber: 'Telefonnummer',
	popupDependent: 'Avhenging (Netscape)',
	popupFeatures: 'Egenskaper for popup-vindu',
	popupFullScreen: 'Fullskjerm (IE)',
	popupLeft: 'Venstre posisjon',
	popupLocationBar: 'Adresselinje',
	popupMenuBar: 'Menylinje',
	popupResizable: 'Skalerbar',
	popupScrollBars: 'Scrollbar',
	popupStatusBar: 'Statuslinje',
	popupToolbar: 'Verktøylinje',
	popupTop: 'Topp-posisjon',
	rel: 'Relasjon (rel)',
	selectAnchor: 'Velg et anker',
	styles: 'Stil',
	tabIndex: 'Tabindeks',
	target: 'Mål',
	targetFrame: '<ramme>',
	targetFrameName: 'Målramme',
	targetPopup: '<popup-vindu>',
	targetPopupName: 'Navn på popup-vindu',
	title: 'Lenke',
	toAnchor: 'Lenke til anker i teksten',
	toEmail: 'E-post',
	toUrl: 'URL',
	toPhone: 'Telefon',
	toolbar: 'Sett inn/Rediger lenke',
	type: 'Lenketype',
	unlink: 'Fjern lenke',
	upload: 'Last opp'
} );
